@@ -4,9 +4,7 @@
  * GChemPaint library
  * application.cc 
  *
- * Copyright (C) 2004-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -147,29 +145,33 @@ gcpApplication::gcpApplication ()
 			if (value) {
 				MailAgent = value;
 				int i = MailAgent.find (" %s");
-				if (i)
+				if (i > 0)
 					MailAgent.erase (i, MailAgent.size ());
 			}
 		}
 	}
 
 	// search help file
-	string lang = getenv ("LANG");
-	HelpFilename = string (DATADIR"/gnome/help/") + string (PACKAGE"/") + lang + "/"PACKAGE".xml";
-	struct stat buf;
-	int err = stat(HelpFilename.c_str (), &buf);
-	if (err) {
+	char const *szlang = getenv ("LANG");
+	string lang = (szlang)? szlang: "C";
+	HelpFilename = string ("file://"DATADIR"/gnome/help/") + string (PACKAGE"/") + lang + "/"PACKAGE".xml";
+	GnomeVFSURI *uri = gnome_vfs_uri_new (HelpFilename.c_str ());
+	bool exists = gnome_vfs_uri_exists (uri);
+	gnome_vfs_uri_unref (uri);
+	if (!exists) {
 		if (lang.size () > 2) {
 			lang.erase (2, lang.size());
-			HelpFilename = string (DATADIR"/gnome/help/"PACKAGE"/") + lang + "/"PACKAGE".xml";
-			err = stat(HelpFilename.c_str (), &buf);
+			HelpFilename = string ("file://"DATADIR"/gnome/help/"PACKAGE"/") + lang + "/"PACKAGE".xml";
+			uri = gnome_vfs_uri_new (HelpFilename.c_str ());
 		}
-		if (err) {
-			HelpFilename = DATADIR"/gnome/help/"PACKAGE"/C/"PACKAGE".xml";
-			err = stat(HelpFilename.c_str (), &buf);
+		if (!exists) {
+			HelpFilename = "file://"DATADIR"/gnome/help/"PACKAGE"/C/"PACKAGE".xml";
+			uri = gnome_vfs_uri_new (HelpFilename.c_str ());
+			exists = gnome_vfs_uri_exists (uri);
+			gnome_vfs_uri_unref (uri);
 		}
 	}
-	if (err) {
+	if (!exists) {
 		g_warning("Help file not found");
 		HelpFilename = "";
 	}
@@ -295,7 +297,7 @@ void gcpApplication::SetStatusText(const char* text)
 
 void gcpApplication::OnSaveAs()
 {
-	gcpFileChooser* fc = new gcpFileChooser (this, true, m_pActiveDoc);
+	new gcpFileChooser (this, true, m_pActiveDoc);
 }
 
 void gcpApplication::AddUI (const char* filename)
@@ -307,7 +309,10 @@ void gcpApplication::AddUI (const char* filename)
 	else 
 	{
 		BonoboUINode *Child, *Next;
-		if (!strcmp(bonobo_ui_node_get_name(Parent), "Root")) Node = bonobo_ui_node_children (Parent);
+		if (!strcmp(bonobo_ui_node_get_name (Parent), "Root"))
+			Node = bonobo_ui_node_children (Parent);
+		else
+			Node = NULL;
 		while (Node)
 		{
 			const char* name = bonobo_ui_node_get_name (Node);
@@ -397,7 +402,6 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 				break;
 		}
 	gchar* filename2;
-	struct stat buf;
 	bool err;
 	GnomeVFSURI *uri;
 	if (bSave)
@@ -615,7 +619,7 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 	}
 	catch (int num)
 	{
-		gchar *mess;
+		gchar *mess = NULL;
 		GtkWidget* message;
 		switch (num)
 		{
@@ -628,6 +632,8 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 		case 2:
 			mess = g_strdup_printf(_("%s: parse error."), filename);
 			break;
+		default:
+			throw (num); //this should not occur
 		}
 		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
 		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
@@ -651,7 +657,7 @@ static int	cb_vfs_to_xml (GnomeVFSHandle *handle, char* buf, int nb)
 
 void gcpApplication::OpenGcp(const gchar* filename, gcpDocument* pDoc)
 {
-	xmlDocPtr xml;
+	xmlDocPtr xml = NULL;
 	char *old_num_locale, *old_time_locale;
 	GnomeVFSFileInfo *info = NULL;
 	try
@@ -705,7 +711,7 @@ void gcpApplication::OpenGcp(const gchar* filename, gcpDocument* pDoc)
 		if (info)
 			gnome_vfs_file_info_unref (info);
 		if (num > 1) xmlFreeDoc(xml);
-		gchar *mess;
+		gchar *mess = NULL;
 		GtkWidget* message;
 		switch (num)
 		{
@@ -724,6 +730,8 @@ void gcpApplication::OpenGcp(const gchar* filename, gcpDocument* pDoc)
 		case 4:
 			mess = g_strdup_printf(_("%s: parse error."), filename);
 			break;
+		default:
+			throw (num); //this should not occur
 		}
 		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
 		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
